@@ -72,7 +72,7 @@
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #endif
-#include "ldns/ldns.h"
+#include <ldns/ldns.h>
 #include <signal.h>
 #include "libunbound/unbound.h"
 #ifdef HAVE_SYS_STAT_H
