@@ -356,12 +356,12 @@ test_threaded_table(struct slabhash* table)
 	if(0) slabhash_status(table, "hashtest", 1);
 }
 
-void slabhash_test()
+void slabhash_test(void)
 {
 	/* start very very small array, so it can do lots of table_grow() */
 	/* also small in size so that reclaim has to be done quickly. */
 	struct slabhash* table;
-	printf("slabhash test\n");
+	unit_show_feature("slabhash");
 	table = slabhash_create(4, 2, 10400, 
 		test_slabhash_sizefunc, test_slabhash_compfunc, 
 		test_slabhash_delkey, test_slabhash_deldata, NULL);
