@@ -39,7 +39,6 @@
 #include "config.h"
 #include <ldns/ldns.h>
 #include "util/data/msgparse.h"
-#include "util/net_help.h"
 #include "util/data/dname.h"
 #include "util/data/packed_rrset.h"
 #include "util/storage/lookup3.h"
@@ -655,8 +654,10 @@ calc_size(ldns_buffer* pkt, uint16_t type, struct rr_parse* rr)
 				len = 0;
 				break;
 			case LDNS_RDF_TYPE_STR:
-				if(pkt_len < 1)
+				if(pkt_len < 1) {
+					/* NOTREACHED, due to 'while(>0)' */
 					return 0; /* len byte exceeds rdata */
+				}
 				len = ldns_buffer_current(pkt)[0] + 1;
 				break;
 			default:
